<?xml version="1.0"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">
	<xsl:output method="xml"
							doctype-system="xhtml-math-svg.dtd"
							doctype-public="-//W3C//DTD XHTML 1.1 plus MathML 2.0 plus SVG 1.1//EN"
     					encoding="ISO-8859-1"
     					indent="yes"/>
     					
<!-- ******************************************************************************************** -->
<!-- MiLCA XSLT Stylesheet -->
<!-- Fragen und Anregungen: Maik Stuehrenberg, JLU Giessen -->
<!-- zuletzt geaendert am: 05-06-2002, 15:40 -->
<!-- ******************************************************************************************** -->

<!-- Template fuer das root-Element LearningObject -->
<!-- Die Verarbeitung erfolgt in mehreren Schritten: -->
<!-- 1. Erzeugung einer Ausgabedatei -->
<!-- 2. Erstellung eines Inhaltsverzeichnisses -->
<!-- Dabei wird jeweils dem AggregationLevel unterschieden -->
	<xsl:template match="LearningObject">
		<xsl:choose>
			<xsl:when test="MetaData/General/@AggregationLevel>=3">
<!-- Level 3 und hoeher erhalten ein Inhaltsverzeichnis -->			
				<xsl:variable name="index">
					<xsl:value-of select="concat(MetaData/General/@Identifier,'.xhtml')"/>
				</xsl:variable>
				<xsl:document href="{$index}">
					<html>
						<head>
							<xsl:apply-templates select="MetaData"/>
							<link type="text/css" rel="stylesheet">
								<xsl:attribute name="href">
									<xsl:value-of select="LayoutInformation/@CSS-URL"/>
								</xsl:attribute>
							</link>
						</head>
						<body>
							<h1>
								<xsl:value-of select="MetaData/General/Title"/>
							</h1>
							<p>
								<xsl:choose>
									<xsl:when test="MetaData/General/Language='de'">
										<b>Zusammenfassung:</b>
									</xsl:when>
									<xsl:when test="MetaData/General/Language='en'">
										<b>Abstract:</b>
									</xsl:when>
									<xsl:otherwise>
										<b>Abstract:</b>
									</xsl:otherwise>
								</xsl:choose>
								<br/>
								<xsl:apply-templates select="MetaData/General/Description"/>
							</p>	
<!-- Erzeugen des Inhaltsverzeichnisses -->
<!-- Jedes LearningObject mit einem AggregationLevel > 1 wird in das Inhaltsverzeichnis aufgenommen -->					
							<xsl:choose>
								<xsl:when test="MetaData/General/Language='de'">
									<h2>Inhalt</h2>
								</xsl:when>
								<xsl:when test="MetaData/General/Language='en'">
									<h2>Table of Contents</h2>
								</xsl:when>
								<xsl:otherwise>
									<h2>Table of Contents</h2>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:for-each select="Content/LearningObject">
								<xsl:choose>
									<xsl:when test="MetaData/General/@AggregationLevel>1">
										<xsl:variable name="LOfile">
											<xsl:value-of select="concat(MetaData/General/@Identifier,'.xhtml')"/>
										</xsl:variable>
										<p>
											<a>
												<xsl:attribute name="href">	
													<xsl:value-of select="$LOfile"/>
												</xsl:attribute>
												<xsl:value-of select="MetaData/General/Title"/>
											</a>
											<br/>
											<xsl:value-of select="MetaData/General/Description"/>
										</p>								
									</xsl:when>
								</xsl:choose>
							</xsl:for-each>
							<xsl:apply-templates select="Test"/>
							<xsl:apply-templates select="bibliography"/>
							<xsl:apply-templates select="Glossary"/>
						</body>
					</html>
				</xsl:document>
			</xsl:when>
			<xsl:when test="MetaData/General/@AggregationLevel=2">
<!-- LearningObjects mit Level 2 werden als HTML-Seiten ausgegeben -->			
				<xsl:variable name="LO">
					<xsl:value-of select="concat(MetaData/General/@Identifier,'.xhtml')"/>
				</xsl:variable>
				<xsl:document href="{$LO}">
					<html>
						<head>
							<xsl:apply-templates select="MetaData"/>
							<link type="text/css" rel="stylesheet">
								<xsl:attribute name="href">
									<xsl:value-of select="LayoutInformation/@CSS-URL"/>
								</xsl:attribute>
							</link>
						</head>
						<body>
							<h1>
								<xsl:value-of select="MetaData/General/Title"/>
							</h1>
							<p>
								<xsl:choose>
									<xsl:when test="MetaData/General/Language='de'">
										<b>Zusammenfassung:</b>
									</xsl:when>
									<xsl:when test="MetaData/General/Language='en'">
										<b>Abstract:</b>
									</xsl:when>
									<xsl:otherwise>
										<b>Abstract:</b>
									</xsl:otherwise>
								</xsl:choose>
								<br/>
								<xsl:value-of select="MetaData/General/Description"/>
							</p>
							<xsl:apply-templates select="Content"/>
							<xsl:apply-templates select="Test"/>
							<xsl:apply-templates select="bibliography"/>
							<xsl:apply-templates select="Glossary"/>
						</body>
					</html>
				</xsl:document>
			</xsl:when>
			<xsl:when test="MetaData/General/@AggregationLevel=1">
				<xsl:choose>
					<xsl:when test="MetaData/Technical/@Format='image-gif'">
						<img>
							<xsl:attribute name="src">
								<xsl:value-of select="MetaData/Technical/Location"/>
							</xsl:attribute>
						</img>
						<span class="Image"><xsl:text>Abbildung </xsl:text>
						<xsl:number count="LearningObject"/>
						<xsl:text>: </xsl:text>
						<xsl:value-of select="MetaData/General/Title"/>
						</span>
					</xsl:when>
					<xsl:when test="MetaData/Technical/@Format='image-jpeg'">
						<img>
							<xsl:attribute name="src">
								<xsl:value-of select="MetaData/Technical/Location"/>
							</xsl:attribute>
						</img>
						<span class="Image"><xsl:text>Abbildung </xsl:text>
						<xsl:number count="LearningObject"/>
						<xsl:text>: </xsl:text>
						<xsl:value-of select="MetaData/General/Title"/>
						</span>
					</xsl:when>		
					<xsl:when test="MetaData/Technical/@Format='image-png'">
						<img>
							<xsl:attribute name="src">
								<xsl:value-of select="MetaData/Technical/Location"/>
							</xsl:attribute>
						</img>
						<span class="Image"><xsl:text>Abbildung </xsl:text>
						<xsl:number count="LearningObject"/>
						<xsl:text>: </xsl:text>
						<xsl:value-of select="MetaData/General/Title"/>
						</span>
					</xsl:when>
					<xsl:otherwise>
						<a>
							<xsl:attribute name="href">
								<xsl:value-of select="MetaData/Technical/Location"/>
							</xsl:attribute>
							<xsl:value-of select="MetaData/General/Title"/>
						</a>
					</xsl:otherwise>								
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>
	
<!-- Template fuer die MetaDaten -->
<!-- In HTML verwendete MetaDaten wie Titel, Autor, Description und Keywords werden weitergerreicht -->
	<xsl:template match="MetaData">
		<xsl:for-each select="Lifecycle/Contribute/Entity">
			<xsl:if test="@Role='Author'">
				<meta name="author">
					<xsl:attribute name="content">
						<xsl:choose>
							<xsl:when test="vCard">
								<xsl:value-of select="vCard/FN"/>		
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</meta>
			</xsl:if>
		</xsl:for-each>
		<xsl:if test="General/@AggregationLevel>1">
			<meta name="description">
				<xsl:attribute name="content">
					<xsl:value-of select="General/Description"/>
				</xsl:attribute>
			</meta>
			<meta name="keywords">
				<xsl:attribute name="content">
					<xsl:value-of select="General/Keywords"/>
				</xsl:attribute>
			</meta>
			<title>
				<xsl:value-of select="General/Title"/>
			</title>
		</xsl:if>
	</xsl:template>
	
<!-- Template fuer den Inhalt -->
	<xsl:template match="Content">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Text">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Headline">
		<h2><xsl:apply-templates/></h2>
	</xsl:template>
	
	<xsl:template match="Paragraph">
		<p>
		<xsl:apply-templates/>
		</p>
	</xsl:template>
	
<!-- Besondere Behandlung fuer Absaetze, die in Listen eingebettet sind -->	
	<xsl:template match="Item/Paragraph">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Definition/Paragraph">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="Link">
		<a target="_blank">
			<xsl:attribute name="href">
 				<xsl:value-of select="@href"/>
 			</xsl:attribute>
 			<xsl:attribute name="title">
 				<xsl:value-of select="@title"/>
 			</xsl:attribute>
 			<xsl:value-of select="."/>
		</a>
	</xsl:template>
	
<!-- Emph und Strong werden nach HTML durchgereicht -->
<!-- Je nach Grund der Hervorhebung wird eine CSS-Klasse genutzt -->
	<xsl:template match="Emph">
		<em>
			<xsl:choose>
				<xsl:when test="@Reason='Keyword'">
					<xsl:attribute name="class">
						<xsl:text>Keyword</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='Intuition'">
					<xsl:attribute name="class">
						<xsl:text>Intuition</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='MetaLanguageUse'">
					<xsl:attribute name="class">
						<xsl:text>MetaLanguageUse</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
		</em>
 	</xsl:template>
 	
 	<xsl:template match="Strong">
 		<strong>
 			<xsl:choose>
				<xsl:when test="@Reason='Keyword'">
					<xsl:attribute name="class">
						<xsl:text>Keyword</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='Intuition'">
					<xsl:attribute name="class">
						<xsl:text>Intuition</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="@Reason='MetaLanguageUse'">
					<xsl:attribute name="class">
						<xsl:text>MetaLanguageUse</xsl:text>
					</xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
 		</strong>
 	</xsl:template>
 	
<!-- Woertliche Zitate -->
<!-- Zitate werden in Anfuehrungszeichen gesetzt -->
<!-- Wenn es eine Referenz gibt, dann wird der Autor der Referenz genannt -->
<!-- Gibt es mehrere Autoren, werden sie durch Kommata getrennt -->
<!-- Anschliessend erfolgt die Nennung des Jahres und einer evtl. vorhandenen Seitenangabe --> 
 	<xsl:template match="Quotation">
 		<xsl:choose>
 			<xsl:when test="@Type='Block'">
				<blockquote>
					<xsl:text>"</xsl:text>
					<xsl:apply-templates/>
					<xsl:text>"</xsl:text>
					<xsl:if test="@Reference_to">
 						<xsl:choose>
 							<xsl:when test="id(@Reference_to)/author">
 								<xsl:for-each select="id(@Reference_to)/author">
 									<xsl:apply-templates select="lastname"/>
 									<xsl:choose>
										<xsl:when test="position()!=last()">
											<xsl:text>, </xsl:text>
										</xsl:when>
									</xsl:choose> 				
								</xsl:for-each>
							</xsl:when>
							<xsl:when test="id(@Reference_to)/editor">
								<xsl:for-each select="id(@Reference_to)/editor">
 									<xsl:apply-templates select="lastname"/>
 									<xsl:choose>
										<xsl:when test="position()!=last()">
											<xsl:text>, </xsl:text>
										</xsl:when>
									</xsl:choose> 				
								</xsl:for-each>
							</xsl:when>
						</xsl:choose>
 						<xsl:text>, </xsl:text>
 						<xsl:apply-templates select="id(@Reference_to)/year"/>
 						<xsl:if test="@Page">
 							<xsl:text>, S. </xsl:text>
 							<xsl:apply-templates select="@Page"/>
 						</xsl:if>
 					</xsl:if>
				</blockquote>
 			</xsl:when>
 			<xsl:otherwise> 			
 				<xsl:text>"</xsl:text><xsl:apply-templates/><xsl:text>"</xsl:text>
 				<xsl:if test="@Reference_to">
 					<xsl:choose>
 						<xsl:when test="id(@Reference_to)/author">
 							<xsl:for-each select="id(@Reference_to)/author">
 								<xsl:apply-templates select="lastname"/>/>
 								<xsl:choose>
									<xsl:when test="position()!=last()">
										<xsl:text>, </xsl:text>
									</xsl:when>
								</xsl:choose> 				
							</xsl:for-each>
						</xsl:when>
						<xsl:when test="id(@Reference_to)/editor">
							<xsl:for-each select="id(@Reference_to)/editor">
 								<xsl:apply-templates select="lastname"/>
 								<xsl:choose>
									<xsl:when test="position()!=last()">
										<xsl:text>, </xsl:text>
									</xsl:when>
								</xsl:choose> 				
							</xsl:for-each>
						</xsl:when>
					</xsl:choose>
 					<xsl:text>, </xsl:text>
 					<xsl:apply-templates select="id(@Reference_to)/year"/>
 					<xsl:if test="Page">
 						<xsl:text>, S. </xsl:text>
 						<xsl:apply-templates select="@Page"/>
 					</xsl:if>
 				</xsl:if>
 			</xsl:otherwise>
 		</xsl:choose>
 	</xsl:template>
 	
 	<xsl:template match="Entity">
<!-- vCard oder PCDATA ? -->
		<xsl:choose>
			<xsl:when test="vCard">
				<xsl:value-of select="vCard/FN"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
 	</xsl:template>
 	
 	<xsl:template match="Code">
 		<xsl:choose>
 			<xsl:when test="@Display='Block'">
 				<div class="CodeBlock">
 					<xsl:apply-templates/>
 				</div>
 			</xsl:when>
 			<xsl:otherwise>
 				<xsl:choose>
 					<xsl:when test="CodeElem">
 						<xsl:apply-templates/>
 					</xsl:when>
 					<xsl:otherwise>
 						<span class="Code">
 							<xsl:apply-templates/>
 						</span>
 					</xsl:otherwise>
 				</xsl:choose>
			</xsl:otherwise>
 		</xsl:choose>
 	</xsl:template>
 	
 	<xsl:template match="CodeElem">
 		<span class="Code">
 			<xsl:apply-templates/>
 			<br/>
 		</span>
 	</xsl:template>
 	
 	<xsl:template match="List">
 		<xsl:choose>
			<xsl:when test="@Type='ordered'">
				<xsl:for-each select="Title">
					<br/>
					<xsl:apply-templates select="."/>
				</xsl:for-each>	
				<ol>
					<xsl:apply-templates select="Item"/>
 				</ol>
 			</xsl:when>	
 			<xsl:otherwise>
			<xsl:for-each select="Title">
				<br/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>	
 			<ul>
 				<xsl:apply-templates select="Item"/>
 			</ul>
 			</xsl:otherwise>
 		</xsl:choose>
 	</xsl:template>	
 	
 	<xsl:template match="Item">
		<li>
		<xsl:apply-templates/>
		</li>
	</xsl:template>
	
	<xsl:template match="Formula">
		<xsl:choose>
 			<xsl:when test="@Display='Block'">
 				<div class="Formula">
 					<xsl:copy-of select="node()"/>
 				</div>
 			</xsl:when>
 			<xsl:otherwise>
 				<xsl:copy-of select="node()"/>
 			</xsl:otherwise>
 		</xsl:choose>
	</xsl:template>
	
<!-- Innerhalb eines LearningObjects werden die Tabellen automatisch durchnummeriert -->
<!-- Attribute werden nach HTML durchgereicht -->
	<xsl:template match="Table">
		<xsl:for-each select="Title">
			<xsl:value-of select="."/>
		<br/>
		</xsl:for-each>
		<table>
		<xsl:for-each select="@Width">
			<xsl:attribute name="width">
				<xsl:value-of select="."/>
			</xsl:attribute>
		</xsl:for-each>
		<xsl:for-each select="@Height">
			<xsl:attribute name="height">
				<xsl:value-of select="."/>
			</xsl:attribute>
		</xsl:for-each>
		<xsl:for-each select="@Border">
			<xsl:attribute name="border">
				<xsl:value-of select="."/>
			</xsl:attribute>
		</xsl:for-each>
		<xsl:if test="Summary">
			<xsl:attribute name="summary">
				<xsl:value-of select="Summary"/>
			</xsl:attribute>
		</xsl:if>
		<xsl:if test="HeaderCaption">
			<caption align="top">
			<xsl:choose>
			<xsl:when test="../@Language='de'">
			<xsl:text>Tabelle </xsl:text>
			</xsl:when>
			<xsl:when test="../@Language='en'">
			<xsl:text>Table </xsl:text>
			</xsl:when>
			</xsl:choose>
			<xsl:number count="Table"/><xsl:text>: </xsl:text>
			<xsl:value-of select="HeaderCaption"/>
			</caption>
		</xsl:if>
		<xsl:if test="FooterCaption">
			<caption align="bottom">
			<xsl:value-of select="FooterCaption"/>
			</caption>
		</xsl:if>
		<xsl:for-each select="TableRow">
			<tr>
				<xsl:for-each select="TableData">
					<td>
						<xsl:value-of select="."/>
					</td>
				</xsl:for-each>
			</tr>
		</xsl:for-each>
		</table>
	</xsl:template>
	
	<xsl:template match="Glossary">
		<xsl:choose>
			<xsl:when test="../MetaData/General/Language='de'">
				<h1>Glossar</h1>
			</xsl:when>
			<xsl:when test="../MetaData/General/Language='en'">
				<h1>Glossary</h1>
			</xsl:when>
		</xsl:choose>
		<table width="90%">
		<xsl:for-each select="GlossaryItem">
			<tr>
			<xsl:attribute name="id">
			<xsl:value-of select="GlossaryTerm/@Definition"/>
			</xsl:attribute>
				<xsl:for-each select="GlossaryTerm">
					<td valign="top" width="20%"><xsl:value-of select="."/></td>
				</xsl:for-each>
				<xsl:for-each select="DefinitionList">
					<td>
						<xsl:for-each select="Definition">
							<xsl:apply-templates/>
						</xsl:for-each>
					</td>
				</xsl:for-each>
				<xsl:for-each select="Definition">
					<td valign="top"><xsl:apply-templates select="."/></td>
				</xsl:for-each>
			</tr>
		</xsl:for-each>
		</table>
	</xsl:template>
	
	<xsl:template match="GlossaryTerm">
		<a class="GlossaryTerm">
			<xsl:attribute name="title">
				<xsl:value-of select="id(@Definition)/."/>
			</xsl:attribute>
			<xsl:attribute name="href">
				<xsl:value-of select="concat(id(@Definition)/../../../MetaData/General/@Identifier,'.xhtml','#',@Definition)"/>
			</xsl:attribute>
			<xsl:apply-templates/>
		</a> 
	</xsl:template>
	
	<xsl:template match="Definition">
		<xsl:apply-templates/>
	</xsl:template>
	
<!-- how to resolve the target of the reference? if it is a bibliographical link -->
<!-- it should link to the anker position on the bibliography -->
<!-- if it is a textlink it should link to the position in the text -->
<!-- if it is a learningobject link it should link to the learningobject html file -->
	<xsl:template match="Reference">
		<xsl:choose>
			<xsl:when test="@Type='RefTarget'">
				<a>
					<xsl:attribute name="href">
						<xsl:value-of select="id(@Reference_to)/../../../../MetaData/General/@Identifier"/>
						<xsl:text>.xhtml</xsl:text>
						<xsl:text>#</xsl:text>
						<xsl:value-of select="@Reference_to"/>
					</xsl:attribute>
					<xsl:text>></xsl:text>
					<xsl:apply-templates/>
				</a>
			</xsl:when>
			<xsl:when test="@Type='BibliographyEntry'">
				<xsl:choose>
 					<xsl:when test="id(@Reference_to)/author">
 						<xsl:for-each select="id(@Reference_to)/author">
 							<xsl:apply-templates select="lastname"/>
 							<xsl:choose>
								<xsl:when test="position()!=last()">
									<xsl:text>, </xsl:text>
								</xsl:when>
							</xsl:choose> 				
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="id(@Reference_to)/editor">
						<xsl:for-each select="id(@Reference_to)/editor">
							<xsl:apply-templates select="lastname"/>
 							<xsl:choose>
								<xsl:when test="position()!=last()">
									<xsl:text>, </xsl:text>
								</xsl:when>
							</xsl:choose> 				
						</xsl:for-each>
					</xsl:when>
				</xsl:choose>
				<xsl:text>, </xsl:text>
 				<xsl:apply-templates select="id(@Reference_to)/year"/>
 				<xsl:if test="@Page">
 					<xsl:text>, S. </xsl:text>
 					<xsl:apply-templates select="@Page"/>
 				</xsl:if>
 			</xsl:when>
 			<xsl:when test="@Type='LearningObject'">
 				<xsl:choose>
 					<xsl:when test="id(@Reference_to)/../Technical/@Format='image-jpeg'">
 						<a target="_blank">
 							<xsl:attribute name="href">
 								<xsl:value-of select="id(@Reference_to)/../Technical/Location"/>
 							</xsl:attribute>
 							<xsl:text>>> </xsl:text>
 							<xsl:value-of select="id(@Reference_to)/Title"/>
 						</a>
 					</xsl:when>
 					<xsl:when test="id(@Reference_to)/../Technical/@Format='image-gif'">
 						<a target="_blank">
 							<xsl:attribute name="href">
 								<xsl:value-of select="id(@Reference_to)/../Technical/Location"/>
 							</xsl:attribute>
 							<xsl:text> >></xsl:text>
 							<xsl:value-of select="id(@Reference_to)/Title"/>
 						</a>
 					</xsl:when>
 					<xsl:when test="id(@Reference_to)/../Technical/@Format='image-png'">
 						<a target="_blank">
 							<xsl:attribute name="href">
 								<xsl:value-of select="id(@Reference_to)/../Technical/Location"/>
 							</xsl:attribute>
 							<xsl:text> >> </xsl:text>
 							<xsl:value-of select="id(@Reference_to)/Title"/>
 						</a>
 					</xsl:when>
 					<xsl:otherwise>
 						<a>
 							<xsl:attribute name="href">
 								<xsl:value-of select="@Reference_to"/>
 								<xsl:text>.xhtml</xsl:text>
 							</xsl:attribute>
 							<!-- link to the correct html-file (and maybe the anker position) -->
 							<xsl:text>>></xsl:text>
 							<xsl:value-of select="id(@Reference_to)/Title"/>
 						</a>
 					</xsl:otherwise>
 				</xsl:choose>
 			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="RefTarget">
		<span>
		<xsl:attribute name="id">
			<xsl:value-of select="@Id"/>
		</xsl:attribute>
		<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="LinguisticExamples">
		<p>
			<xsl:apply-templates/>
		</p>
	</xsl:template>
	
	<xsl:template match="LinguisticExample">
		<xsl:text>(</xsl:text>
		<xsl:value-of select="@Id"/>
		<xsl:text>) </xsl:text>
		<xsl:choose>
			<xsl:when test="@Status='ill-formed'">
				<xsl:text>*</xsl:text>
			</xsl:when>
			<xsl:when test="@Status='questionable'">
				<xsl:text>?</xsl:text>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="ExampleText">
		<div class="Indent"><xsl:apply-templates/></div>
	</xsl:template>
	
	<xsl:template match="Gloss">
		<span class="Indent"><xsl:apply-templates/></span>
	</xsl:template>
	
	<xsl:template match="Formalisation">
		<span class="Indent"><xsl:apply-templates/></span>
	</xsl:template>
	
	<xsl:template match="Transcription">
		<span class="Indent"><xsl:apply-templates/></span>
	</xsl:template>
	
	<xsl:template match="Translation">
		<span class="Indent"><xsl:apply-templates/></span>
	</xsl:template>
	
	<xsl:template match="bibliography">
		<xsl:choose>
			<xsl:when test="../MetaData/General/Language='de'">
				<h1>Literaturangaben</h1>
			</xsl:when>
			<xsl:when test="../MetaData/General/Language='en'">
				<h1>Literature</h1>
			</xsl:when>
		</xsl:choose>
		<xsl:for-each select="bibitem">
		<p>
		<xsl:apply-templates select="."/>
		</p>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="bibitem">
		<xsl:choose>
			<xsl:when test="author">
				<xsl:for-each select="author">
					<xsl:apply-templates select="lastname"/>
					<xsl:if test="firstname | middlename | suffix">
						<xsl:text>, </xsl:text>
						<xsl:apply-templates select="firstname"/>
						<xsl:apply-templates select="middlename"/>
						<xsl:apply-templates select="suffix"/>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="position()=last()">
							<xsl:text>, </xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>/</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</xsl:when>
			<xsl:when test="editor">
				<xsl:for-each select="editor">
					<xsl:apply-templates select="lastname"/>
					<xsl:if test="firstname | middlename | suffix">
						<xsl:text>, </xsl:text>
						<xsl:apply-templates select="firstname"/>
						<xsl:apply-templates select="middlename"/>
						<xsl:apply-templates select="suffix"/>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="position()=last()">
							<xsl:text>(Hrsg.), </xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>/</xsl:text>
						</xsl:otherwise>
					</xsl:choose>			
				</xsl:for-each>
			</xsl:when>	
		</xsl:choose>	
		<xsl:text> "</xsl:text>
		<xsl:choose>
			<xsl:when test="@type='Internet'">
				<a>
					<xsl:attribute name="href">
						<xsl:value-of select="URL"/>
					</xsl:attribute>
					<xsl:value-of select="title"/>
				</a>
				<xsl:text>".</xsl:text>
				<br/>
				<xsl:if test="edition">
					<xsl:value-of select="edition"/>
					<br/>
				</xsl:if>
				<xsl:if test="publisher">
					<xsl:apply-templates select="publisher"/>
					<xsl:text>, </xsl:text>	
				</xsl:if>
				<xsl:value-of select="year"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="title"/>
				<xsl:value-of select="booktitle"/>
				<xsl:text>".</xsl:text>
				<br/>
				<xsl:if test="edition">
					<xsl:value-of select="edition"/>
					<br/>
				</xsl:if>
				<xsl:if test="publisher">
					<xsl:apply-templates select="publisher"/>
					<xsl:text>, </xsl:text>	
				</xsl:if>
				<xsl:value-of select="address"/>
				<xsl:text>, </xsl:text>
				<xsl:value-of select="year"/>
			</xsl:otherwise>
		</xsl:choose>		
		
	</xsl:template>

</xsl:stylesheet>